@@ -19,6 +19,7 @@ class MovieConfig:
     input_image_dir: Path
     output_movie_path: Path
     width: int = 1280
+    height: int = 720
     image_type: str = 'png'
     frame_rate: int = 4
     max_frame_rate: int = 4
@@ -27,13 +28,20 @@ class MovieConfig:
     def __post_init__(self):
         if self.frame_rate > self.max_frame_rate:
             raise ValueError(f'frame_rate should be less than {self.max_frame_rate}')
+        # Unity video player width and height should be even number.
         if self.width % 2 != 0:
             self.width += 1
+        if self.height % 2 != 0:
+            self.height += 1
+        # File format should be mp4.
         if self.output_movie_path.suffix != '.mp4':
             self.output_movie_path = Path(f"{self.output_movie_path}.mp4")
 
 
 class BaseConfig(metaclass=ABCMeta):
+    """
+    This class is used to create a hash of the config object.
+    """
     fps = 1
 
     def __post_init__(self) -> None:
@@ -50,9 +58,18 @@ class BaseConfig(metaclass=ABCMeta):
 
 @dataclass
 class ImageConfig(BaseConfig):
+    """
+    This class used to Input Image Config.
+    :param image_dir: image directory path.
+    :param width: image width.
+    :param height: image height.
+    :param max_width: max image width.
+    :param max_height: max image height.
+    """
     image_dir: Path
     width: int = 1280
     height: int = 720
+    # limit of image size.
     max_width = 1920
     max_height = 1920
 
@@ -63,15 +80,31 @@ class ImageConfig(BaseConfig):
 
 @dataclass
 class BrowserConfig(BaseConfig):
+    """
+    This class used to Browser Config.
+    locale is set by lang.
+    :param url: url.
+    :param width: browser width.
+    :param height: browser height.
+    :param page_height: page height.
+    :param scroll: scroll.
+    :param traget: select target file name or type.
+    :param lang: browser language.
+    :param max_width: max browser width.
+    :param max_height: max browser height.
+    :param max_page_height: max page height.
+    :param min_scroll: min scroll.
+    :param driver: driver path.
+    :param page_load_timeout: page load timeout.
+    """
     # user inputs
     url: str = ''
     width: int = 1280
     height: int = 720
     page_height: int = 50000
     scroll: int = 200
-    targets: List[str] = None
-    locale: str = 'en_US'
     lang: str = 'en-US'
+    targets: List[str] = None
     # limits for browser
     min_scroll = 200
     min_page_height = 3000
@@ -81,10 +114,12 @@ class BrowserConfig(BaseConfig):
     # driver settings
     driver_path = Path(__file__).parent
     page_load_timeout = 20
+    # set in __post_init__
+    locale: str = 'en_US'
 
     def __post_init__(self):
         if self.url != '': self.domain = self.url.split("/")[2]
-        self.lang = self.locale.replace('_', '-')
+        self.locale = self.lang.replace('-', '_')
         super().__post_init__()
 
     def apply_limit(self) -> None:
